@@ -1,10 +1,11 @@
-__version__ = "2.1.0"
-__released__ = "2021-01-18"
+__version__ = "2.2"
+__released__ = "2022-11-19"
 
 from .sshconfig import (
     VNC,
     HostEntry,
     NetworkEntry,
+    filter_algorithms,
     get_network_name,
     is_ip_addr,
     locations,
